==> haskell-asn1-encoding-0.9.5-86-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-BJSvqDJDx54IPJiXnFLbIv
key: asn1-encoding-0.9.5-BJSvqDJDx54IPJiXnFLbIv
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
abi: 3ccba298eeed286720673f1c61274470
exposed: True
exposed-modules:
    Data.ASN1.BinaryEncoding Data.ASN1.BinaryEncoding.Raw
    Data.ASN1.Encoding Data.ASN1.Error Data.ASN1.Object
    Data.ASN1.Stream
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-encoding-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-BJSvqDJDx54IPJiXnFLbIv
depends:
    asn1-types-0.3.2-9EHsiBYRqUhKidaP0Vcp2k base-4.12.0.0
    bytestring-0.10.8.2 hourglass-0.2.12-20lGi55db0q5BGitfKmVUp
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-encoding-0.9.5-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-JlMVXuzAd3r1xeJzCIDfY5
key: asn1-encoding-0.9.5-JlMVXuzAd3r1xeJzCIDfY5
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
abi: 82568cc40d347175fc746c16f0db5086
exposed: True
exposed-modules:
    Data.ASN1.BinaryEncoding Data.ASN1.BinaryEncoding.Raw
    Data.ASN1.Encoding Data.ASN1.Error Data.ASN1.Object
    Data.ASN1.Stream
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-encoding-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-JlMVXuzAd3r1xeJzCIDfY5
depends:
    asn1-types-0.3.2-662ZFPfVm6V3hVAaeDyZld base-4.12.0.0
    bytestring-0.10.8.2 hourglass-0.2.12-x2a5xgH6pqLl8VHm9iIl7
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
